@@ -215,15 +215,19 @@ NumericMatrix eval_expansion
   (SEXP ptr, NumericVector const x, NumericMatrix const weights, int const ders,
    double lower_limit){
   Rcpp::XPtr<joint_bases::basisMixin> basis(ptr);
+  NumericMatrix out(basis->n_basis(), x.size());
+  if(out.nrow() == 0 or out.ncol() == 0)
+    return out;
+
   if(basis->n_weights()!=static_cast<unsigned>(weights.nrow()))
     throw std::invalid_argument("Number of weights does not match");
 
-  NumericMatrix out(basis->n_basis(), x.size());
-
   std::unique_ptr<double[]> wmem(new double[basis->n_wmem()]);
   basis->set_lower_limit(lower_limit);
   for(R_len_t i = 0; i < x.size(); ++i)
-    (*basis)(&out.column(i)[0], wmem.get(), x[i], &weights(0,i), ders);
+    (*basis)(&out(0, i), wmem.get(), x[i],
+	     basis->n_weights()!=0 ? &weights(0,i) : nullptr,
+	     ders);
 
   return out;
 }
@@ -590,8 +594,10 @@ public:
 
       input_dat.emplace_back(
         &X[0], n_fixef, n_obs, &id[0], &time[0], &y[0],
-        &fixef_design_varying[0], fixef_design_varying.nrow(),
-        &rng_design_varying[0], rng_design_varying.nrow());
+        fixef_design_varying.nrow()>0 ? &fixef_design_varying[0] : nullptr,
+	fixef_design_varying.nrow(),
+        rng_design_varying.nrow()>0 ? &rng_design_varying[0] : nullptr,
+	rng_design_varying.nrow());
       par_idx.add_marker
         ({n_fixef, bases_fix.back()->n_basis(), bases_rng.back()->n_basis()});
     }
@@ -650,11 +656,11 @@ public:
         (survival::obs_input{n_obs, &y[0], &y[y.nrow()], &y[2 * y.nrow()]});
       s_fixef_design.emplace_back(&Z[0], n_fixef, n_obs);
       s_fixef_design_varying.emplace_back
-        (&fixef_design_varying[0], fixef_design_varying.nrow(),
-         fixef_design_varying.ncol());
+        (fixef_design_varying.nrow()>0 ? &fixef_design_varying[0] : nullptr,
+	 fixef_design_varying.nrow(), fixef_design_varying.ncol());
       s_rng_design_varying.emplace_back
-        (&rng_design_varying[0], rng_design_varying.nrow(),
-         rng_design_varying.ncol());
+        (rng_design_varying.nrow()>0 ? &rng_design_varying[0] : nullptr,
+	 rng_design_varying.nrow(), rng_design_varying.ncol());
       par_idx.add_surv
         ({n_fixef, bases_fix_surv.back()->n_basis(), n_associations,
          with_frailty});
@@ -690,13 +696,13 @@ public:
 
       vajoint_uint const n_fixef = Z.nrow(),
                          n_obs   = Z.ncol();
-      d_fixef_design.emplace_back(&Z[0], n_fixef, n_obs);
+      d_fixef_design.emplace_back(n_obs>0 ? &Z[0] : nullptr, n_fixef, n_obs);
       d_fixef_design_varying_mats.emplace_back
-        (&fixef_design_varying[0], fixef_design_varying.nrow(),
-         fixef_design_varying.ncol());
+        (fixef_design_varying.nrow()>0 ? &fixef_design_varying[0] : nullptr,
+	 fixef_design_varying.nrow(), fixef_design_varying.ncol());
       d_rng_design_varying_mats.emplace_back
-        (&rng_design_varying[0], rng_design_varying.nrow(),
-         rng_design_varying.ncol());
+        (rng_design_varying.nrow()>0 ? &rng_design_varying[0] : nullptr,
+	 rng_design_varying.nrow(), rng_design_varying.ncol());
     }
 
     // construct the objects to compute the different terms of the lower bound
@@ -1313,10 +1319,10 @@ List ph_ll
 
   auto expansion = basis_from_list(time_fixef);
   simple_mat Z_sm(&Z[0], Z.nrow(), Z.ncol()),
-             fixef_design_varying_sm(&fixef_design_varying[0],
+    fixef_design_varying_sm(fixef_design_varying.nrow()>0 ? &fixef_design_varying[0] : nullptr,
                                      fixef_design_varying.nrow(),
                                      fixef_design_varying.ncol()),
-             rng_design_varying_sm(&rng_design_varying[0],
+    rng_design_varying_sm(rng_design_varying.nrow()>0 ? &rng_design_varying[0] : nullptr,
                                    rng_design_varying.nrow(),
                                    rng_design_varying.ncol()),
              surv_sm(&surv[0], surv.nrow(), surv.ncol());
